/*
 * Copyright (C) 2008 Gauvain Pocentek <gpocentek@linutop.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <stdio.h>

#include <gmodule.h>
#include <glib/gprintf.h>
#include <glib/gstdio.h>
#include <gtk/gtk.h>
#include <libxfce4util/libxfce4util.h>

#include "appstarter.h"

int main (int argc, char *argv[])
{
    GtkWidget *dialog, *chooser;
    GtkWidget *d;
    XfceKiosk *kiosk;
    gchar *conffile = NULL;
    gchar *select = NULL;
    gboolean selected = FALSE;
    gchar *with_ss = NULL;
    gchar *command = NULL;

    GOptionEntry options[] = {
        { "conffile", 'c', 0, G_OPTION_ARG_STRING,
          &conffile, N_("Use the specified configuration file"), "FILE" },
        { "select", 's', 0, G_OPTION_ARG_STRING,
          &select, N_("Set the selected item to be PLUGIN and exit"), "PLUGIN" },
        { "command", 'r', 0, G_OPTION_ARG_STRING,
          &command, N_("Set the command to be CMD and exit"), "CMD" },
        { "selected", 'w', 0, G_OPTION_ARG_NONE,
          &selected, N_("Show the plugin currently selected"), NULL },
        { "with-ss", 's', 0, G_OPTION_ARG_STRING,
          &with_ss, N_("If BOOL is \"false\", disable the screen saver"),"BOOL" },

        { NULL },
    };

    if (!gtk_init_with_args (&argc, &argv, "", options, PACKAGE, NULL)) {
        g_print ( _(
            "%s:\nTry %s --help to see a full list of available command line options.\n"),
                PACKAGE, PACKAGE_NAME);
        return 1;
    }

    kiosk = xfce_kiosk_new ("AppStarter");
    if (!xfce_kiosk_query (kiosk, "Allowed"))
    {
        d = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL,
                       GTK_MESSAGE_WARNING, GTK_BUTTONS_CLOSE,
                       _("You are not allowed to run this application."));
        gtk_dialog_run (GTK_DIALOG (d));
        goto out;
    }

    if (! conffile)
        conffile = xfce_get_homefile (".config", "appstarterrc", NULL);

    if (selected)
    {
        XfceRc *rc= as_rc_open (conffile, TRUE);
        xfce_rc_set_group (rc, "default");

        printf ("%s", xfce_rc_read_entry (rc, "selected", ""));
        xfce_rc_close (rc);
        goto out;
    }

    if (select || command || with_ss)
    {
        XfceRc *rc = as_rc_open (conffile, FALSE);
        xfce_rc_set_group (rc, "default");

        if (with_ss)
        {
            xfce_rc_write_bool_entry (rc, "noscreensaver",
                                      g_strcmp0 (with_ss, "false") == 0);
            g_free (with_ss);
        }
        if (select)
        {
            xfce_rc_write_entry (rc, "selected", select);
            g_free (select);
        }
        if (command)
        {
            xfce_rc_write_entry (rc, "command", command);
            g_free (command);
        }

        xfce_rc_close (rc);
        goto out;
    }

    dialog = gtk_dialog_new_with_buttons("AppStarter",
                                         NULL,
                                         GTK_DIALOG_MODAL,
                                         GTK_STOCK_OK,
                                         GTK_RESPONSE_ACCEPT,
                                         NULL);
    gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
    gtk_window_set_default_icon_name ("system-run");

    chooser = as_chooser_new ((const gchar *) conffile);
    g_free (conffile);
    gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), chooser);
    gtk_widget_show (chooser);

    if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT)
        as_chooser_save (AS_CHOOSER (chooser));

    gtk_widget_destroy (dialog);

out:
    xfce_kiosk_free (kiosk);
    return 0;
}
